DockBase class abstract base

DOCK ABSTRACT BASE CLASS

Constructors

DockBase()

Properties

defaultOnEmptyWidgetBuilder ↔ WidgetCallbackViaContext?
Default on empty widget builder
getter/setter pair
defaultOnErrorWidgetBuilder ↔ WidgetCallbackViaContext?
Default on error widget builder
getter/setter pair
defaultOnLoadingWidgetBuilder ↔ WidgetCallbackViaContext?
Default on loading widget builder
getter/setter pair
defaultOnOfflineWidgetBuilder ↔ WidgetCallbackViaContext?
Default on offline widget builder
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testBindings ↔ WidgetsBinding?
WidgetsBinding only for testing
getter/setter pair
widgetsBinding → WidgetsBinding
WidgetsBinding instance
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited